@@ -1,6 +1,4 @@
-use flemish::{
-    button::Button, frame::Frame, Flex, OnEvent, Sandbox, Settings
-};
+use flemish::{button::Button, frame::Frame, prelude::*, Flex, OnEvent, Sandbox, Settings};
 
 pub fn main() {
     Counter::new().run(Settings {
@@ -21,8 +19,6 @@ enum Message {
     DecrementPressed,
 }
 
-impl OnEvent<Message> for Button {}
-
 impl Sandbox for Counter {
     type Message = Message;
 
@@ -46,7 +42,7 @@ impl Sandbox for Counter {
     }
 
     fn view(&mut self) -> Flex {
-        let mut col = Flex::default().with_type(fltk_flex::FlexType::Column);
+        let mut col = Flex::default().column();
         let mut button1 = Button::default().with_label("Increment");
         button1.on_event(Message::IncrementPressed);
         Frame::default().with_label(&self.value.to_string());
